==> zio-aws-mgn_2.13-5.17.157.1-sources.jar: zio/aws/mgn/model/DescribeSourceServersRequest.scala <==
package zio.aws.mgn.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.mgn.model.primitives.{PaginationToken, StrictlyPositiveInteger}
import scala.jdk.CollectionConverters._
final case class DescribeSourceServersRequest(
    filters: zio.aws.mgn.model.DescribeSourceServersRequestFilters,
    maxResults: Option[StrictlyPositiveInteger] = None,
    nextToken: Option[PaginationToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mgn.model.DescribeSourceServersRequest = {
    import DescribeSourceServersRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mgn.model.DescribeSourceServersRequest
      .builder()
      .filters(filters.buildAwsValue())
      .optionallyWith(
        maxResults.map(value => StrictlyPositiveInteger.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.mgn.model.DescribeSourceServersRequest.ReadOnly =
    zio.aws.mgn.model.DescribeSourceServersRequest.wrap(buildAwsValue())
}
object DescribeSourceServersRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mgn.model.DescribeSourceServersRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mgn.model.DescribeSourceServersRequest =
      zio.aws.mgn.model.DescribeSourceServersRequest(
        filters.asEditable,
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def filters: zio.aws.mgn.model.DescribeSourceServersRequestFilters.ReadOnly
    def maxResults: Option[StrictlyPositiveInteger]
    def nextToken: Option[PaginationToken]
    def getFilters: ZIO[
      Any,
      Nothing,
      zio.aws.mgn.model.DescribeSourceServersRequestFilters.ReadOnly
    ] = ZIO.succeed(filters)
    def getMaxResults: ZIO[Any, AwsError, StrictlyPositiveInteger] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mgn.model.DescribeSourceServersRequest
  ) extends zio.aws.mgn.model.DescribeSourceServersRequest.ReadOnly {
    override val filters
        : zio.aws.mgn.model.DescribeSourceServersRequestFilters.ReadOnly =
      zio.aws.mgn.model.DescribeSourceServersRequestFilters.wrap(impl.filters())
    override val maxResults: Option[StrictlyPositiveInteger] = scala
      .Option(impl.maxResults())
      .map(value => zio.aws.mgn.model.primitives.StrictlyPositiveInteger(value))
    override val nextToken: Option[PaginationToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.mgn.model.primitives.PaginationToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.mgn.model.DescribeSourceServersRequest
  ): zio.aws.mgn.model.DescribeSourceServersRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-mgn_2.13-5.17.295.13-sources.jar: zio/aws/mgn/model/DescribeSourceServersRequest.scala <==
package zio.aws.mgn.model
import zio.aws.mgn.model.primitives.{PaginationToken, StrictlyPositiveInteger}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class DescribeSourceServersRequest(
    filters: Optional[zio.aws.mgn.model.DescribeSourceServersRequestFilters] =
      Optional.Absent,
    maxResults: Optional[StrictlyPositiveInteger] = Optional.Absent,
    nextToken: Optional[PaginationToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mgn.model.DescribeSourceServersRequest = {
    import DescribeSourceServersRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mgn.model.DescribeSourceServersRequest
      .builder()
      .optionallyWith(filters.map(value => value.buildAwsValue()))(_.filters)
      .optionallyWith(
        maxResults.map(value => StrictlyPositiveInteger.unwrap(value): Integer)
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.mgn.model.DescribeSourceServersRequest.ReadOnly =
    zio.aws.mgn.model.DescribeSourceServersRequest.wrap(buildAwsValue())
}
object DescribeSourceServersRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mgn.model.DescribeSourceServersRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mgn.model.DescribeSourceServersRequest =
      zio.aws.mgn.model.DescribeSourceServersRequest(
        filters.map(value => value.asEditable),
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def filters: Optional[
      zio.aws.mgn.model.DescribeSourceServersRequestFilters.ReadOnly
    ]
    def maxResults: Optional[StrictlyPositiveInteger]
    def nextToken: Optional[PaginationToken]
    def getFilters: ZIO[
      Any,
      AwsError,
      zio.aws.mgn.model.DescribeSourceServersRequestFilters.ReadOnly
    ] = AwsError.unwrapOptionField("filters", filters)
    def getMaxResults: ZIO[Any, AwsError, StrictlyPositiveInteger] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mgn.model.DescribeSourceServersRequest
  ) extends zio.aws.mgn.model.DescribeSourceServersRequest.ReadOnly {
    override val filters: Optional[
      zio.aws.mgn.model.DescribeSourceServersRequestFilters.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.filters())
      .map(value =>
        zio.aws.mgn.model.DescribeSourceServersRequestFilters.wrap(value)
      )
    override val maxResults: Optional[StrictlyPositiveInteger] =
      zio.aws.core.internal
        .optionalFromNullable(impl.maxResults())
        .map(value =>
          zio.aws.mgn.model.primitives.StrictlyPositiveInteger(value)
        )
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.mgn.model.primitives.PaginationToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.mgn.model.DescribeSourceServersRequest
  ): zio.aws.mgn.model.DescribeSourceServersRequest.ReadOnly = new Wrapper(impl)
}
